diff -Naur linux-2.5.73/drivers/md/dm-ioctl.c linux-2.5.73-evms-2.0.1/drivers/md/dm-ioctl.c
--- linux-2.5.73/drivers/md/dm-ioctl.c	2003-06-17 08:53:13.000000000 -0500
+++ linux-2.5.73-evms-2.0.1/drivers/md/dm-ioctl.c	2003-06-17 08:50:29.000000000 -0500
@@ -399,7 +400,7 @@
  * Round up the ptr to the next 'align' boundary.  Obviously
  * 'align' must be a power of 2.
  */
-static inline void *align_ptr(void *ptr, unsigned int align)
+static inline void *align_ptr(void *ptr, unsigned long align)
 {
 	align--;
 	return (void *) (((unsigned long) (ptr + align)) & ~align);
@@ -884,7 +885,16 @@
 		return -ENXIO;
 	}
 
+	if (param->flags & DM_SUSPEND_FLAG) {
+		dm_suspend(md);
+	}
+
 	r = dm_swap_table(md, t);
+
+	if (param->flags & DM_SUSPEND_FLAG) {
+		dm_resume(md);
+	}
+
 	if (r) {
 		dm_put(md);
 		dm_table_put(t);
diff -Naur linux-2.5.73/drivers/md/dm-table.c linux-2.5.73-evms-2.0.1/drivers/md/dm-table.c
--- linux-2.5.73/drivers/md/dm-table.c	2003-06-17 08:53:13.000000000 -0500
+++ linux-2.5.73-evms-2.0.1/drivers/md/dm-table.c	2003-06-17 08:50:29.000000000 -0500
@@ -746,7 +746,7 @@
 	q->seg_boundary_mask = t->limits.seg_boundary_mask;
 }
 
-unsigned int dm_table_get_num_targets(struct dm_table *t)
+int dm_table_get_num_targets(struct dm_table *t)
 {
 	return t->num_targets;
 }
diff -Naur linux-2.5.73/drivers/md/dm.h linux-2.5.73-evms-2.0.1/drivers/md/dm.h
--- linux-2.5.73/drivers/md/dm.h	2003-06-17 08:53:13.000000000 -0500
+++ linux-2.5.73-evms-2.0.1/drivers/md/dm.h	2003-06-17 08:50:29.000000000 -0500
@@ -101,7 +101,7 @@
 struct dm_target *dm_table_get_target(struct dm_table *t, unsigned int index);
 struct dm_target *dm_table_find_target(struct dm_table *t, sector_t sector);
 void dm_table_set_restrictions(struct dm_table *t, struct request_queue *q);
-unsigned int dm_table_get_num_targets(struct dm_table *t);
+int dm_table_get_num_targets(struct dm_table *t);
 struct list_head *dm_table_get_devices(struct dm_table *t);
 int dm_table_get_mode(struct dm_table *t);
 void dm_table_add_wait_queue(struct dm_table *t, wait_queue_t *wq);
diff -Naur linux-2.5.73/include/linux/dm-ioctl.h linux-2.5.73-evms-2.0.1/include/linux/dm-ioctl.h
--- linux-2.5.73/include/linux/dm-ioctl.h	2003-06-17 08:53:13.000000000 -0500
+++ linux-2.5.73-evms-2.0.1/include/linux/dm-ioctl.h	2003-06-17 08:51:05.000000000 -0500
@@ -46,11 +46,11 @@
 	uint32_t data_start;	/* offset to start of data
 				 * relative to start of this struct */
 
-	uint32_t target_count;	/* in/out */
-	uint32_t open_count;	/* out */
+	int32_t target_count;	/* in/out */
+	int32_t open_count;	/* out */
 	uint32_t flags;		/* in/out */
 
-	__kernel_dev_t dev;	/* in/out */
+	uint64_t dev;		/* in/out */
 
 	char name[DM_NAME_LEN];	/* device name */
 	char uuid[DM_UUID_LEN];	/* unique identifier for
@@ -62,9 +62,9 @@
  * dm_ioctl.
  */
 struct dm_target_spec {
-	int32_t status;		/* used when reading from kernel only */
 	uint64_t sector_start;
-	uint32_t length;
+	uint64_t length;
+	int32_t status;		/* used when reading from kernel only */
 
 	/*
 	 * Offset in bytes (from the start of this struct) to
@@ -85,9 +85,9 @@
  * Used to retrieve the target dependencies.
  */
 struct dm_target_deps {
-	uint32_t count;
-
-	__kernel_dev_t dev[0];	/* out */
+	uint32_t count;		/* Array size */
+	uint32_t padding;	/* unused */
+	uint64_t dev[0];	/* out */
 };
 
 /*
@@ -129,10 +129,10 @@
 #define DM_TARGET_STATUS _IOWR(DM_IOCTL, DM_TARGET_STATUS_CMD, struct dm_ioctl)
 #define DM_TARGET_WAIT   _IOWR(DM_IOCTL, DM_TARGET_WAIT_CMD, struct dm_ioctl)
 
-#define DM_VERSION_MAJOR	1
+#define DM_VERSION_MAJOR	3
 #define DM_VERSION_MINOR	0
-#define DM_VERSION_PATCHLEVEL	6
-#define DM_VERSION_EXTRA	"-ioctl (2002-10-15)"
+#define DM_VERSION_PATCHLEVEL	0
+#define DM_VERSION_EXTRA	"-ioctl (2003-03-28)"
 
 /* Status bits */
 #define DM_READONLY_FLAG	0x00000001
